summaryrefslogtreecommitdiffstats
path: root/tqtinterface/qt4/tools/designer/uic/form.cpp
diff options
context:
space:
mode:
Diffstat (limited to 'tqtinterface/qt4/tools/designer/uic/form.cpp')
-rw-r--r--tqtinterface/qt4/tools/designer/uic/form.cpp36
1 files changed, 18 insertions, 18 deletions
diff --git a/tqtinterface/qt4/tools/designer/uic/form.cpp b/tqtinterface/qt4/tools/designer/uic/form.cpp
index 11a0a69..728a1fd 100644
--- a/tqtinterface/qt4/tools/designer/uic/form.cpp
+++ b/tqtinterface/qt4/tools/designer/uic/form.cpp
@@ -192,7 +192,7 @@ void Uic::createFormDecl( const TQDomElement &e )
// register the object and unify its name
objName = registerObject( objName );
TQString protector = objName.upper() + "_H";
- protector.tqreplace( "::", "_" );
+ protector.replace( "::", "_" );
out << "#ifndef " << protector << endl;
out << "#define " << protector << endl;
out << endl;
@@ -204,7 +204,7 @@ void Uic::createFormDecl( const TQDomElement &e )
TQStringList globalIncludes, localIncludes;
int wid = WidgetDatabase::idFromClassName( objClass );
{
- TQMap<TQString, CustomInclude>::Iterator it = customWidgetIncludes.tqfind( objClass );
+ TQMap<TQString, CustomInclude>::Iterator it = customWidgetIncludes.find( objClass );
if ( it != customWidgetIncludes.end() ) {
if ( ( *it ).location == "global" )
globalIncludes += (*it).header;
@@ -230,7 +230,7 @@ void Uic::createFormDecl( const TQDomElement &e )
TQDomElement n2 = nl.item(i).toElement();
TQString s = n2.firstChild().toText().data();
if ( n2.attribute( "impldecl", "in implementation" ) == "in declaration" &&
- n2.attribute( "location" ) == "local" &&!globalIncludes.tqcontains( s ) ) {
+ n2.attribute( "location" ) == "local" &&!globalIncludes.contains( s ) ) {
if ( s.right( 5 ) == ".ui.h" )
continue;
localIncludes += s;
@@ -292,7 +292,7 @@ void Uic::createFormDecl( const TQDomElement &e )
continue; // hide qlayoutwidgets
if ( s == "Line" )
s = "TQFrame";
- if ( !(nofwd && customWidgets.tqcontains(s)) )
+ if ( !(nofwd && customWidgets.contains(s)) )
forwardDecl += s;
if ( s.mid( 2 ) == "ListBox" || s.mid( 2 ) == "ListView" || s.mid( 2 ) == "IconView" )
forwardDecl += "TQ" + s.mid( 2 ) + "Item";
@@ -325,7 +325,7 @@ void Uic::createFormDecl( const TQDomElement &e )
TQDomElement n2 = nl.item(i).toElement();
TQString s = n2.firstChild().toText().data();
if ( n2.attribute( "impldecl", "in implementation" ) == "in declaration" &&
- n2.attribute( "location" ) == "local" &&!globalIncludes.tqcontains( s ) )
+ n2.attribute( "location" ) == "local" &&!globalIncludes.contains( s ) )
localIncludes += s;
}
nl = e.parentNode().toElement().elementsByTagName( "exportmacro" );
@@ -547,7 +547,7 @@ void Uic::createFormDecl( const TQDomElement &e )
writeFunctionsDecl( publicSlots, publicSlotTypes, publicSlotSpecifier );
}
- // tqfind Q_SIGNALS
+ // find Q_SIGNALS
TQStringList extraSignals;
nl = e.parentNode().toElement().elementsByTagName( "signal" );
for ( i = 0; i < (int) nl.length(); i++ ) {
@@ -644,9 +644,9 @@ void Uic::writeFunctionsDecl( const TQStringList &fuLst, const TQStringList &typ
if ( *it3 == "pure virtual" || *it3 == "pureVirtual" )
pure = " = 0";
}
- type.tqreplace( ">>", "> >" );
- if ( !signature.tqcontains("operator") )
- signature.tqreplace( ">>", "> >" );
+ type.replace( ">>", "> >" );
+ if ( !signature.contains("operator") )
+ signature.replace( ">>", "> >" );
out << " " << specifier << type << " " << signature << pure << ";" << endl;
}
out << endl;
@@ -673,7 +673,7 @@ void Uic::createFormImpl( const TQDomElement &e )
TQMap<TQString, CustomInclude> customWidgetIncludes;
// tqfind additional Q_SLOTS and functions
TQStringList extraFuncts;
TQStringList extraFunctTyp;
TQStringList extraFunctSpecifier;
@@ -778,7 +778,7 @@ void Uic::createFormImpl( const TQDomElement &e )
for ( i = 0; i < (int) nl.length(); i++ ) {
TQDomElement n2 = nl.item(i).toElement();
TQString s = n2.firstChild().toText().data();
- if ( n2.attribute( "location" ) == "local" &&!globalIncludes.tqcontains( s ) ) {
+ if ( n2.attribute( "location" ) == "local" &&!globalIncludes.contains( s ) ) {
if ( s.right( 5 ) == ".ui.h" && !TQFile::exists( s ) )
continue;
if ( n2.attribute( "impldecl", "in implementation" ) != "in implementation" )
@@ -812,7 +812,7 @@ void Uic::createFormImpl( const TQDomElement &e )
globalIncludes += "tqheader.h";
if ( name != objClass ) {
int wid = WidgetDatabase::idFromClassName( name );
- TQMap<TQString, CustomInclude>::Iterator it = customWidgetIncludes.tqfind( name );
+ TQMap<TQString, CustomInclude>::Iterator it = customWidgetIncludes.find( name );
if ( it == customWidgetIncludes.end() )
globalIncludes += WidgetDatabase::includeFile( wid );
}
@@ -837,7 +837,7 @@ void Uic::createFormImpl( const TQDomElement &e )
out << "#include <tqtoolbar.h>" << endl;
}
// tqfind out what images are required
TQStringList requiredImages;
static const char *imgTags[] = { "pixmap", "iconset", 0 };
for ( i = 0; imgTags[i] != 0; i++ ) {
@@ -885,7 +885,7 @@ void Uic::createFormImpl( const TQDomElement &e )
nl = n.elementsByTagName( "image" );
for ( i = 0; i < (int) nl.length(); i++ ) {
TQString img = registerObject( nl.item(i).toElement().attribute("name") );
- if ( !requiredImages.tqcontains( img ) )
+ if ( !requiredImages.contains( img ) )
continue;
TQDomElement tmp = nl.item(i).firstChild().toElement();
if ( tmp.tagName() != "data" )
@@ -1047,7 +1047,7 @@ void Uic::createFormImpl( const TQDomElement &e )
if ( objClass == "TQWizard" ) {
for ( n = e.firstChild().toElement(); !n.isNull(); n = n.nextSibling().toElement() ) {
- if ( tags.tqcontains( n.tagName() ) ) {
+ if ( tags.contains( n.tagName() ) ) {
TQString page = createObjectImpl( n, objClass, "this" );
TQString comment;
TQString label = DomTool::readAttribute( n, "title", "", comment ).toString();
@@ -1068,7 +1068,7 @@ void Uic::createFormImpl( const TQDomElement &e )
}
} else { // standard widgets
for ( n = e.firstChild().toElement(); !n.isNull(); n = n.nextSibling().toElement() ) {
- if ( tags.tqcontains( n.tagName() ) )
+ if ( tags.contains( n.tagName() ) )
createObjectImpl( n, objName, "this" );
}
}
@@ -1213,7 +1213,7 @@ void Uic::createFormImpl( const TQDomElement &e )
}
}
- if ( extraFuncts.tqfind( "init()" ) != extraFuncts.end() )
+ if ( extraFuncts.find( "init()" ) != extraFuncts.end() )
out << indent << "init();" << endl;
// end of constructor
@@ -1226,7 +1226,7 @@ void Uic::createFormImpl( const TQDomElement &e )
out << " */" << endl;
out << nameOfClass << "::~" << bareNameOfClass << "()" << endl;
out << "{" << endl;
- if ( extraFuncts.tqfind( "destroy()" ) != extraFuncts.end() )
+ if ( extraFuncts.find( "destroy()" ) != extraFuncts.end() )
out << indent << "destroy();" << endl;
out << indent << "// no need to delete child widgets, TQt does it all for us" << endl;
out << "}" << endl;
@@ -673,7 +673,7 @@ void Uic::createFormImpl( const TQDomElement &e )
TQMap<TQString, CustomInclude> customWidgetIncludes;
- // tqfind additional Q_SLOTS and functions
+ // find additional Q_SLOTS and functions
TQStringList extraFuncts;
TQStringList extraFunctTyp;
@@ -837,7 +837,7 @@ void Uic::createFormImpl( const TQDomElement &e )
out << "#include <tqtoolbar.h>" << endl;
}
- // tqfind out what images are required
+ // find out what images are required
TQStringList requiredImages;
static const char *imgTags[] = { "pixmap", "iconset", 0 };